==> freediams_0.4.2.orig.tar.gz: freediams-0.4.2/global_resources/translations/patientbaseplugin_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de_DE">
<context>
    <name>PatientBar</name>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientbar.ui" line="96"/>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientbar.ui" line="138"/>
        <source>Name, Secondname - surname</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PatientSelector</name>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientselector.ui" line="14"/>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientselector.ui" line="20"/>
        <source>Search</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Patients</name>
    <message>
        <location filename="../../plugins/patientbaseplugin/constants_trans.h" line="53"/>
        <source>Search by Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/constants_trans.h" line="54"/>
        <source>Search by Surname</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/constants_trans.h" line="55"/>
        <source>Search by Name and Surname</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/constants_trans.h" line="56"/>
        <source>Search by Date Of Birth</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/constants_trans.h" line="58"/>
        <source>Type the name or second name of the patient</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/constants_trans.h" line="59"/>
        <source>Type the surname of the patient</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/constants_trans.h" line="60"/>
        <source>Type the name or second name followed by ; and the surname</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/constants_trans.h" line="61"/>
        <source>Type the date of birth (yyyy/MM/dd)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Patients::IdentityPage</name>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientcreatorwizard.cpp" line="98"/>
        <source>Please enter the patient&apos;s identity.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Patients::IdentityWidget</name>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.cpp" line="191"/>
        <source>born on</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.cpp" line="204"/>
        <source>You must specify a birthname.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.cpp" line="205"/>
        <source>You can not create a patient without a birthname</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.cpp" line="206"/>
        <source>No birthname</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.cpp" line="210"/>
        <source>You must specify a surname.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.cpp" line="211"/>
        <source>You can not create a patient without a surname</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.cpp" line="212"/>
        <source>No surname</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.cpp" line="216"/>
        <source>You must specify a date of birth.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.cpp" line="217"/>
        <source>You can not create a patient without a date of birth</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.cpp" line="218"/>
        <source>No date of birth</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.cpp" line="222"/>
        <source>You must specify a gender.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.cpp" line="223"/>
        <source>You can not create a patient without a gender</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.cpp" line="224"/>
        <source>No gender</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.cpp" line="276"/>
        <source>Choose a photo</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Patients::Internal::IdentityViewer</name>
    <message>
        <location filename="../../plugins/patientbaseplugin/identityviewer.ui" line="14"/>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identityviewer.ui" line="163"/>
        <source>Address</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identityviewer.ui" line="186"/>
        <source>Contact</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Patients::Internal::IdentityWidget</name>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.ui" line="14"/>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.ui" line="20"/>
        <source>Identity</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.ui" line="26"/>
        <source>Title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.ui" line="54"/>
        <source>Click to add/change the photo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.ui" line="73"/>
        <source>Birth Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.ui" line="83"/>
        <source>Second name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.ui" line="93"/>
        <source>Surname</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.ui" line="103"/>
        <source>Gender</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.ui" line="113"/>
        <source>Date of birth</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.ui" line="130"/>
        <source>Adress</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.ui" line="136"/>
        <source>Street</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.ui" line="143"/>
        <source>City</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.ui" line="153"/>
        <source>Zipcode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.ui" line="163"/>
        <source>Country</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Patients::Internal::PatientActionHandler</name>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientwidgetmanager.cpp" line="162"/>
        <source>Fatal Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientwidgetmanager.cpp" line="162"/>
        <source>%1 : Unable to retreive patients menu.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Patients::Internal::PatientBase</name>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientbase.cpp" line="249"/>
        <source>Unable to connect the Patient&apos;s database host.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientbase.cpp" line="249"/>
        <location filename="../../plugins/patientbaseplugin/patientbase.cpp" line="255"/>
        <location filename="../../plugins/patientbaseplugin/patientbase.cpp" line="260"/>
        <location filename="../../plugins/patientbaseplugin/patientbase.cpp" line="269"/>
        <source>Please contact dev team.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientbase.cpp" line="255"/>
        <source>Unable to create the Patients database.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientbase.cpp" line="260"/>
        <location filename="../../plugins/patientbaseplugin/patientbase.cpp" line="269"/>
        <source>Unable to connect the Patients database.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Patients::Internal::PatientBasePreferencesWidget</name>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientbasepreferencespage.ui" line="14"/>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientbasepreferencespage.ui" line="26"/>
        <source>Patient database preferences</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientbasepreferencespage.ui" line="43"/>
        <source>Virtual patients</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientbasepreferencespage.ui" line="49"/>
        <source>Show virtual patients</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientbasepreferencespage.ui" line="59"/>
        <source>Patient selector</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientbasepreferencespage.ui" line="65"/>
        <source>Use color to differentiate genders</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientbasepreferencespage.ui" line="88"/>
        <source>Patient bar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientbasepreferencespage.ui" line="94"/>
        <source>Background color</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Patients::PatientCreatorWizard</name>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientcreatorwizard.cpp" line="66"/>
        <source>New Patient</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientcreatorwizard.cpp" line="81"/>
        <source>WARNING ! You don&apos;t saved this patient.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientcreatorwizard.cpp" line="82"/>
        <source>If you continue changes will be lost.
Do you really want to close this dialog ?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientcreatorwizard.cpp" line="84"/>
        <source>Patient not saved</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> freediams_0.5.4.orig.tar.gz: freediams-0.5.4/global_resources/translations/patientbaseplugin_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de_DE">
<context>
    <name>PatientBar</name>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientbar.ui" line="96"/>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientbar.ui" line="138"/>
        <source>Name, Secondname - firstname</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PatientSelector</name>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientselector.ui" line="14"/>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientselector.ui" line="20"/>
        <source>Search</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Patients</name>
    <message>
        <location filename="../../plugins/patientbaseplugin/constants_trans.h" line="53"/>
        <source>Search by Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/constants_trans.h" line="54"/>
        <source>Search by Firstname</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/constants_trans.h" line="55"/>
        <source>Search by Name and Firstname</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/constants_trans.h" line="56"/>
        <source>Search by Date Of Birth</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/constants_trans.h" line="58"/>
        <source>Type the name or second name of the patient</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/constants_trans.h" line="59"/>
        <source>Type the firstname of the patient</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/constants_trans.h" line="60"/>
        <source>Type the name or second name followed by ; and the firstname</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/constants_trans.h" line="61"/>
        <source>Type the date of birth (yyyy/MM/dd)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Patients::IdentityPage</name>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientcreatorwizard.cpp" line="104"/>
        <source>Please enter the patient&apos;s identity.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Patients::IdentityWidget</name>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.cpp" line="191"/>
        <source>born on</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.cpp" line="204"/>
        <source>You must specify a birthname.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.cpp" line="205"/>
        <source>You can not create a patient without a birthname</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.cpp" line="206"/>
        <source>No birthname</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.cpp" line="210"/>
        <source>You must specify a firstname.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.cpp" line="211"/>
        <source>You can not create a patient without a firstname</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.cpp" line="212"/>
        <source>No firstname</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.cpp" line="216"/>
        <source>You must specify a date of birth.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.cpp" line="217"/>
        <source>You can not create a patient without a date of birth</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.cpp" line="218"/>
        <source>No date of birth</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.cpp" line="222"/>
        <source>You must specify a gender.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.cpp" line="223"/>
        <source>You can not create a patient without a gender</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.cpp" line="224"/>
        <source>No gender</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.cpp" line="276"/>
        <source>Choose a photo</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Patients::Internal::IdentityViewer</name>
    <message>
        <location filename="../../plugins/patientbaseplugin/identityviewer.ui" line="14"/>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identityviewer.ui" line="163"/>
        <source>Address</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identityviewer.ui" line="186"/>
        <source>Contact</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Patients::Internal::IdentityWidget</name>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.ui" line="14"/>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.ui" line="20"/>
        <source>Identity</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.ui" line="26"/>
        <source>Title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.ui" line="54"/>
        <source>Click to add/change the photo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.ui" line="73"/>
        <source>Birth Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.ui" line="83"/>
        <source>Second name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.ui" line="93"/>
        <source>Firstname</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.ui" line="103"/>
        <source>Gender</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.ui" line="113"/>
        <source>Date of birth</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.ui" line="130"/>
        <source>Adress</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.ui" line="136"/>
        <source>Street</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.ui" line="143"/>
        <source>City</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.ui" line="153"/>
        <source>Zipcode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/identitywidget.ui" line="163"/>
        <source>Country</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Patients::Internal::PatientActionHandler</name>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientwidgetmanager.cpp" line="162"/>
        <source>Fatal Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientwidgetmanager.cpp" line="162"/>
        <source>%1 : Unable to retreive patients menu.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Patients::Internal::PatientBase</name>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientbase.cpp" line="249"/>
        <source>Unable to connect the Patient&apos;s database host.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientbase.cpp" line="249"/>
        <location filename="../../plugins/patientbaseplugin/patientbase.cpp" line="255"/>
        <location filename="../../plugins/patientbaseplugin/patientbase.cpp" line="260"/>
        <location filename="../../plugins/patientbaseplugin/patientbase.cpp" line="269"/>
        <source>Please contact dev team.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientbase.cpp" line="255"/>
        <source>Unable to create the Patients database.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientbase.cpp" line="260"/>
        <location filename="../../plugins/patientbaseplugin/patientbase.cpp" line="269"/>
        <source>Unable to connect the Patients database.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Patients::Internal::PatientBasePreferencesWidget</name>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientbasepreferencespage.ui" line="14"/>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientbasepreferencespage.ui" line="26"/>
        <source>Patient database preferences</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientbasepreferencespage.ui" line="43"/>
        <source>Virtual patients</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientbasepreferencespage.ui" line="49"/>
        <source>Show virtual patients</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientbasepreferencespage.ui" line="59"/>
        <source>Patient selector</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientbasepreferencespage.ui" line="65"/>
        <source>Use color to differentiate genders</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientbasepreferencespage.ui" line="88"/>
        <source>Patient bar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientbasepreferencespage.ui" line="94"/>
        <source>Background color</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Patients::PatientCreatorWizard</name>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientcreatorwizard.cpp" line="66"/>
        <source>New Patient</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientcreatorwizard.cpp" line="81"/>
        <source>WARNING ! You don&apos;t saved this patient.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientcreatorwizard.cpp" line="82"/>
        <source>If you continue changes will be lost.
Do you really want to close this dialog ?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/patientbaseplugin/patientcreatorwizard.cpp" line="84"/>
        <source>Patient not saved</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
